==> meerschaum-0.4.1-py3-none-any.whl: meerschaum/api/dash/pages/register.py <==
#! /usr/bin/env python3
# -*- coding: utf-8 -*-
# vim:fenc=utf-8

"""
Create new user accounts.
"""

import dash_bootstrap_components as dbc
from meerschaum.utils.packages import import_html, import_dcc
html, dcc = import_html(), import_dcc()

layout = dbc.Container([
    html.Div([
        html.Br(),
        html.H3("Register your account"),
        dbc.Row(
            [
                dbc.Col([
                    #  dbc.FormGroup([
                        dbc.Label("Username", html_for='username-input'),
                        dbc.Input(id="username-input", type="text", placeholder="Enter username"),
                        dbc.FormFeedback("Username is available.", type="valid"),
                        dbc.FormFeedback("Username is unavailable.", type="invalid"),
                    #  ]),
                    ],
                    width = 6,
                ),
                dbc.Col([
                    #  dbc.FormGroup([
                        dbc.Label("Password", html_for='password-input'),
                        dbc.Input(
                            id="password-input", type="password", value="",
                            placeholder='Enter password'
                        ),
                        dbc.FormFeedback("Password is acceptable.", type="valid"),
                        dbc.FormFeedback("Password is too short.", type="invalid"),
                    ],
                    width = 6,
                ),
            ],
            #  form = True,
        ),
        dbc.Row(
            dbc.Col([
                #  dbc.FormGroup([
                    dbc.Label("Email", html_for="email-input"),
                    dbc.Input(id="email-input", type="email", placeholder="Optional"),
                #  ]),
                dbc.FormFeedback("", type="valid"),
                dbc.FormFeedback("", type="invalid"),
                ],
            ),
            #  form = True,
        ),
        html.Br(),
        dbc.Row([
            dbc.Col([
                html.Button(
                    children = 'Sign Up',
                    n_clicks = 0,
                    type = 'submit',
                    id = 'register-button',
                    className = 'btn btn-primary btn-lg'
                ),
            ]),
        ]),

    ])


])

==> meerschaum-1.0.0.dev6-py3-none-any.whl: meerschaum/api/dash/pages/register.py <==
#! /usr/bin/env python3
# -*- coding: utf-8 -*-
# vim:fenc=utf-8

"""
Create new user accounts.
"""

import dash_bootstrap_components as dbc
from meerschaum.utils.packages import import_html, import_dcc
html, dcc = import_html(), import_dcc()

layout = dbc.Container([
    html.Div([
        html.Br(),
        html.H3("Register your account"),
        dbc.Row(
            [
                dbc.Col([
                    #  dbc.FormGroup([
                        dbc.Label("Username", html_for='register-username-input'),
                        dbc.Input(id="register-username-input", type="text", placeholder="Enter username"),
                        dbc.FormFeedback("Username is available.", type="valid"),
                        dbc.FormFeedback("Username is unavailable.", type="invalid"),
                    #  ]),
                    ],
                    width = 6,
                ),
                dbc.Col([
                    #  dbc.FormGroup([
                        dbc.Label("Password", html_for='register-password-input'),
                        dbc.Input(
                            id="register-password-input", type="password", value="",
                            placeholder='Enter password'
                        ),
                        dbc.FormFeedback("Password is acceptable.", type="valid"),
                        dbc.FormFeedback("Password is too short.", type="invalid"),
                    ],
                    width = 6,
                ),
            ],
            #  form = True,
        ),
        html.Br(),
        dbc.Row(
            dbc.Col([
                #  dbc.FormGroup([
                    dbc.Label("Email", html_for="register-email-input"),
                    dbc.Input(id="register-email-input", type="email", placeholder="Optional"),
                #  ]),
                dbc.FormFeedback("", type="valid"),
                dbc.FormFeedback("", type="invalid"),
                ],
            ),
            #  form = True,
        ),
        html.Br(),
        dbc.Row([
            dbc.Col([
                html.Button(
                    children = 'Sign Up',
                    n_clicks = 0,
                    type = 'submit',
                    id = 'register-button',
                    className = 'btn btn-primary btn-lg'
                ),
            ]),
        ]),

    ])


])
